﻿//AddGuides.jsx
//An InDesign CS2 JavaScript
//
//This script draws guides around the selected object or objects.
//Choose Visible Bounds to consider the stroke weight of the paths when placing the guides, 
//or choose Geometric Bounds to ignore the stroke weight when placing the guides
//Choose Each Item to position the guides around individual items in the selection, 
//or Entire Selection to position the guides around the selection as a whole.
//
//For more information on InDesign scripting, go to http://www.adobe.com/products/indesign/scripting.html
//Or visit the InDesign Scripting User to User forum at http://www.adobeforums.com.
//
var myObjectList = new Array;
if (app.documents.length != 0){
	if (app.selection.length != 0){
		for(var myCounter = 0;myCounter < app.selection.length; myCounter++){
			switch (app.selection[myCounter].constructor.name){
				case "Rectangle":
				case "Oval":
				case "Polygon":
				case "TextFrame":
				case "Group":
				case "Button":
				case "GraphicLine":
					myObjectList.push(app.selection[myCounter]);
					break;
			}
		}
		if (myObjectList.length != 0){
			myDisplayDialog(myObjectList);
		}
		else{
			alert ("请选择一个页面再试.");
		}
	}
	else{
		alert ("请选择一个物体再试.");
	}
}
else{
    alert ("请打开一个文档,选择一个物体,再试.");
}
function myDisplayDialog(myObjectList){
	var myDialog, myRangeButtons, myBasedOnButtons;
	with(myDialog = app.dialogs.add({name:"加导线"})){
		with(dialogColumns.add()){
			with(borderPanels.add()){
				staticTexts.add({staticLabel:"加导线在:"});
				with(dialogColumns.add()){					
					var myTopCheckbox = checkboxControls.add({staticLabel:"(&T)顶", checkedState:true});
					var myLeftCheckbox = checkboxControls.add({staticLabel:"(&L)左", checkedState:true});
					var myBottomCheckbox = checkboxControls.add({staticLabel:"(&B)底部", checkedState:true});
					var myRightCheckbox = checkboxControls.add({staticLabel:"(&R)右", checkedState:true});
					var myXCenterCheckbox = checkboxControls.add({staticLabel:"(&H)水平中心", checkedState:true});
					var myYCenterCheckbox = checkboxControls.add({staticLabel:"(&V)垂直中心", checkedState:true});
				}
			}
			with(borderPanels.add()){
				staticTexts.add({staticLabel:"在周围在导线:"});
				with(myRangeButtons = radiobuttonGroups.add()){
					radiobuttonControls.add({staticLabel:"每个对象", checkedState:true});
					radiobuttonControls.add({staticLabel:"整个选择"});
				}
			}
			with(borderPanels.add()){
				staticTexts.add({staticLabel:"导线基于:"});
				with(myBasedOnButtons = radiobuttonGroups.add()){
					radiobuttonControls.add({staticLabel:"&Geometric Bounds", checkedState:true});
					radiobuttonControls.add({staticLabel:"V&isible Bounds"});
				}
			}
		}
	}
	myReturn = myDialog.show();
	if (myReturn == true){
		//Get control values from the dialog box.
		var myTop = myTopCheckbox.checkedState;
		var myLeft = myLeftCheckbox.checkedState;
		var myBottom = myBottomCheckbox.checkedState;
		var myRight = myRightCheckbox.checkedState;
		var myXCenter = myXCenterCheckbox.checkedState;
		var myYCenter = myYCenterCheckbox.checkedState;
		var myBasedOn = myBasedOnButtons.selectedButton;
		var myRange = myRangeButtons.selectedButton;
		//Remove the dialog box from memory.
		myDialog.destroy();
		if(myTop+myLeft+myBottom+myRight+myXCenter+myYCenter !=0){
			myAddGuides(myTop, myLeft, myBottom, myRight, myXCenter, myYCenter, myRange, myBasedOn, myObjectList);
		}
		else{
			alert("No guides were specified.");
		}
	}
	else{
		//Remove the dialog box from memory.
		myDialog.destroy();
	}
}
function myAddGuides(myTop, myLeft, myBottom, myRight, myXCenter, myYCenter, myRange, myBasedOn, myObjectList){
	var myLayer, myCounter;
	var myOldRulerOrigin = app.activeDocument.viewPreferences.rulerOrigin;
	app.activeDocument.viewPreferences.rulerOrigin = RulerOrigin.spineOrigin;
	//Create a layer to hold the printers marks (if it does not already exist).
	myLayer = app.activeDocument.layers.item("Guides");
	try{
		myLayerName = myLayer.name;
	}
	catch (myError){
		myLayer = app.activeDocument.layers.add({name:"Guides"});
	}
	//Process the objects in the selection.		
	for(myCounter = 0; myCounter < myObjectList.length; myCounter ++){
		var myObject = myObjectList[myCounter];
		if (myBasedOn == 0){
			myBounds = myObject.visibleBounds;
		}
		else{
			myBounds = myObject.geometricBounds;
		}
		//Set up some initial bounding box values.
		if ((myRange != 0)&&(myCounter==0)){
			myX1 = myBounds[1];
			myY1 = myBounds[0];
			myX2 = myBounds[3];
			myY2 = myBounds[2];
		}
		if(myRange == 0){
			myDrawGuides (myBounds[1], myBounds[0], myBounds[3], myBounds[2], myTop, myLeft, myBottom, myRight, myXCenter, myYCenter, myLayer);
		}
		else{
			//Compare the bounds values to the stored bounds.
			//If a given bounds value is less than (for x1 and y1) or 
			//greater than (for x2 and y2) the stored value,
			//then replace the stored value with the bounds value.
			if (myBounds[0] < myY1){
				myY1 = myBounds[0];
			}
			if (myBounds[1] < myX1){
				myX1 = myBounds[1];
			}
			if (myBounds[2] > myY2){
				myY2 = myBounds[2];
			}
			if (myBounds[3] > myX2){
				myX2 = myBounds[3];
			}
		}
	}
	if(myRange != 0){
		myDrawGuides (myX1, myY1, myX2, myY2, myTop, myLeft, myBottom, myRight, myXCenter, myYCenter, myLayer);
	}
	app.activeDocument.viewPreferences.rulerOrigin = myOldRulerOrigin;
}
function myDrawGuides(myX1, myY1, myX2, myY2, myTop, myLeft, myBottom, myRight, myXCenter, myYCenter, myLayer){
	if (myTop == true){
		myDrawGuide(myY1, 0);
	}
	if (myLeft == true){
		myDrawGuide(myX1, 1);
	}
	if (myBottom == true){
		myDrawGuide(myY2, 0);
	}
	if (myRight == true){
		myDrawGuide(myX2, 1);
	}
	if (myXCenter == true){
		myDrawGuide(myX1+((myX2-myX1)/2), 1);
	}
	if (myYCenter == true){
		myDrawGuide(myY1+((myY2-myY1)/2), 0);
	}
}
function myDrawGuide(myGuideLocation, myGuideOrientation){
	var myLayer = app.activeDocument.layers.item("Guides");
	with(app.activeWindow.activeSpread){
		if(myGuideOrientation == 0){
			with (guides.add(myLayer, undefined, undefined)){
				orientation=HorizontalOrVertical.horizontal;
				location=myGuideLocation;
			}
		}
		else{
			with (guides.add(myLayer, undefined, undefined)){
				orientation=HorizontalOrVertical.vertical;
				location=myGuideLocation;
			}
		}
	}
}